SketchArrayWriter

Struct SketchArrayWriter 

pub struct SketchArrayWriter { /* private fields */ }
Write to an .skd or .skq file This writer is not parallel safe, serial only!

Implementations

Source

impl SketchArrayWriter

pub fn new( filename: &str, bin_stride: usize, kmer_stride: usize, sample_stride: usize, ) -> Self

Open a new sketch file for writing

pub fn write_sketch<HashSize: ToBytes>( &mut self, usigs_flat: &[HashSize], ) -> usize

Write a single sketch to the currently open file, appending to the end (at the current write position)

Returns:
  • Index in file where sketch was written
pub fn flush(&mut self) -> Result<(), Error>

Flush the underlying writer